# RogueORM
 A high level ORM that strives to get rid of all N+1 issues.

_Note_: This package is still in alpha development. VERY early alpha, none of it can be used as of yet in any kind of project.

The development goal is to first ahve a working SQLite version, then add postgresql support. If you like the way it is built and would like to contribute, don't hesitate to reach out!
